@@ -660,7 +660,7 @@
         }
 
       fb = [SOGoFreeBusyObject objectWithName: @"freebusy.ifb" inContainer: [user homeFolderInContext: context]];
-      fbInfo = [fb fetchFreeBusyInfosFrom: start to: end];
+      fbInfo = (NSMutableArray *)[fb fetchFreeBusyInfosFrom: start to: end];
 
       //
       // We must also check here for repetitive events that don't overlap our event.
@@ -718,6 +718,7 @@
         }
 
       // Find the attendee associated to the current UID
+      currentAttendee = nil;
       for (i = 0; i < [theAttendees count]; i++)
         {
           currentAttendee = [theAttendees objectAtIndex: i];
@@ -783,6 +784,7 @@
               NSMutableDictionary *info;
               NSMutableArray *conflicts;
               NSString *formattedEnd;
+              SOGoUser *ownerUser;
               id o;
 
               info = [NSMutableDictionary dictionary];
@@ -792,10 +794,17 @@
                 {
                   if ([currentAttendee cn])
                     [info setObject: [currentAttendee cn]  forKey: @"attendee_name"];
-
                   if ([currentAttendee rfc822Email])
                     [info setObject: [currentAttendee rfc822Email]  forKey: @"attendee_email"];
                 }
+              else if ([owner isEqualToString: currentUID])
+                {
+                  ownerUser = [SOGoUser userWithLogin: owner];
+                  if ([ownerUser cn])
+                    [info setObject: [ownerUser cn]  forKey: @"attendee_name"];
+                  if ([ownerUser systemEmail])
+                    [info setObject: [ownerUser systemEmail]  forKey: @"attendee_email"];
+                }
 
               for (i = 0; i < [fbInfo count]; i++)
                 {
@@ -804,7 +813,7 @@
                   if ([[o objectForKey: @"startDate"] isDateOnSameDay: end])
                     formattedEnd = [formatter formattedTime: end];
                   else
-                    [formatter formattedDateAndTime: end];
+                    formattedEnd = [formatter formattedDateAndTime: end];
 
                   [conflicts addObject: [NSDictionary dictionaryWithObjectsAndKeys: [formatter formattedDateAndTime: [o objectForKey: @"startDate"]], @"startDate",
                                                       formattedEnd, @"endDate", nil]];
