@@ -6,8 +6,8 @@
   /**
    * @ngInject
    */
-  AclController.$inject = ['$timeout', '$mdDialog', 'Dialog', 'usersWithACL', 'User', 'folder'];
-  function AclController($timeout, $mdDialog, Dialog, usersWithACL, User, folder) {
+  AclController.$inject = ['$document', '$timeout', '$mdDialog', 'Dialog', 'usersWithACL', 'User', 'folder'];
+  function AclController($document, $timeout, $mdDialog, Dialog, usersWithACL, User, folder) {
     var vm = this;
 
     vm.users = usersWithACL; // ACL users
@@ -16,6 +16,8 @@
     vm.selectedUid = null;
     vm.userToAdd = '';
     vm.searchText = '';
+    vm.folderClassName = folderClassName;
+    vm.templateName = templateName;
     vm.userFilter = userFilter;
     vm.closeModal = closeModal;
     vm.saveModal = saveModal;
@@ -24,10 +26,24 @@
     vm.addUser = addUser;
     vm.selectAllRights = selectAllRights;
     vm.selectUser = selectUser;
+    vm.hasNoRight = hasNoRight;
     vm.showRights = showRights;
     vm.confirmation = { showing: false,
                         message: ''};
 
+    function folderClassName() {
+      if (angular.isFunction(folder.getClassName))
+        return folder.getClassName('bg');
+      else
+        return false;
+    }
+
+    function templateName(user) {
+      // Check if user is anonymous and if a specific template must be used
+      var isAnonymous = $document[0].getElementById('UIxAnonymousUserRightsEditor') && user.$isAnonymous();
+      return 'UIx' + (isAnonymous? 'Anonymous' : '') + 'UserRightsEditor';
+    }
+
     function userFilter($query) {
       return User.$filter($query, folder.$acl.users);
     }
@@ -89,6 +105,10 @@
       }
     }
 
+    function hasNoRight(user) {
+      return folder.$acl.$hasNoRight(user);
+    }
+
     function showRights(user) {
       return vm.selectedUid == user.uid && !user.inactive;
     }
