@@ -98,7 +98,10 @@
    * @returns the number of mailboxes in the account
    */
   Account.prototype.getLength = function() {
-    return this.$flattenMailboxes().length;
+    if (this.$expanded)
+      return this.$flattenMailboxes().length;
+    else
+      return 0;
   };
 
   /**
@@ -146,11 +149,20 @@
               });
             };
         if (Account.$Preferences.settings.Mail.ExpandedFolders) {
-          if (angular.isString(Account.$Preferences.settings.Mail.ExpandedFolders))
+          if (angular.isString(Account.$Preferences.settings.Mail.ExpandedFolders)) {
             // Backward compatibility support
-            expandedFolders = angular.fromJson(Account.$Preferences.settings.Mail.ExpandedFolders);
-          else
+            try {
+              expandedFolders = angular.fromJson(Account.$Preferences.settings.Mail.ExpandedFolders);
+            }
+            catch (e) {
+              Account.$log.warn("Can't parse list of expanded folders. String was: " +
+                                Account.$Preferences.settings.Mail.ExpandedFolders);
+              expandedFolders = [];
+            }
+          }
+          else {
             expandedFolders = Account.$Preferences.settings.Mail.ExpandedFolders;
+          }
           _this.$expanded = (expandedFolders.indexOf('/' + _this.id) >= 0);
           if (expandedFolders.length > 0) {
             _visit(_this.$mailboxes);
@@ -278,6 +290,44 @@
     });
   };
 
+  /**
+   * @function $certificate
+   * @memberof Account.prototype
+   * @desc View the S/MIME certificate details associated to the account.
+   * @returns a promise of the HTTP operation
+   */
+  Account.prototype.$certificate = function() {
+    var _this = this;
+
+    if (this.security && this.security.hasCertificate) {
+      if (this.$$certificate)
+        return Account.$q.when(this.$$certificate);
+      else {
+        return Account.$$resource.fetch(this.id.toString(), 'certificate').then(function(data) {
+          _this.$$certificate = data;
+          return data;
+        });
+      }
+    }
+    else {
+      return Account.$q.reject();
+    }
+  };
+
+  /**
+   * @function $removeCertificate
+   * @memberof Account.prototype
+   * @desc Remove any S/MIME certificate associated with the account.
+   * @returns a promise of the HTTP operation
+   */
+  Account.prototype.$removeCertificate = function() {
+    var _this = this;
+
+    return Account.$$resource.fetch(this.id.toString(), 'removeCertificate').then(function() {
+      _this.security.hasCertificate = false;
+    });
+  };
+
   /**
    * @function updateQuota
    * @memberof Account.prototype
@@ -300,7 +350,7 @@
    * @desc Prepare a new Message object associated to the appropriate mailbox.
    * @returns a promise of the HTTP operations
    */
-  Account.prototype.$newMessage = function() {
+  Account.prototype.$newMessage = function(options) {
     var _this = this;
 
     // Query account for draft folder and draft UID
@@ -311,9 +361,22 @@
     }).then(function(message) {
       // Fetch draft initial data
       return Account.$$resource.fetch(message.$absolutePath({asDraft: true}), 'edit').then(function(data) {
+        var accountDefaults = Account.$Preferences.defaults.AuxiliaryMailAccounts[_this.id];
+        if (accountDefaults.security) {
+          if (accountDefaults.security.alwaysSign)
+            data.sign = true;
+          if (accountDefaults.security.alwaysEncrypt)
+            data.encrypt = true;
+        }
         Account.$log.debug('New message (edit): ' + JSON.stringify(data, undefined, 2));
         angular.extend(message.editable, data);
         message.isNew = true;
+        if (options && options.mailto) {
+          if (angular.isObject(options.mailto))
+            angular.extend(message.editable, options.mailto);
+          else
+            message.$parseMailto(options.mailto);
+        }
         return message;
       });
     });
