@@ -6,8 +6,8 @@
   /**
    * @ngInject
    */
-  MailboxesController.$inject = ['$scope', '$state', '$transitions', '$timeout', '$window', '$mdDialog', '$mdToast', 'sgFocus', 'encodeUriFilter', 'Dialog', 'sgSettings', 'sgHotkeys', 'Account', 'Mailbox', 'VirtualMailbox', 'User', 'Preferences', 'stateAccounts'];
-  function MailboxesController($scope, $state, $transitions, $timeout, $window, $mdDialog, $mdToast, focus, encodeUriFilter, Dialog, Settings, sgHotkeys, Account, Mailbox, VirtualMailbox, User, Preferences, stateAccounts) {
+  MailboxesController.$inject = ['$scope', '$state', '$transitions', '$timeout', '$window', '$mdUtil', '$mdMedia', '$mdSidenav', '$mdDialog', '$mdToast', 'sgConstant', 'sgFocus', 'encodeUriFilter', 'Dialog', 'sgSettings', 'sgHotkeys', 'Account', 'Mailbox', 'VirtualMailbox', 'User', 'Preferences', 'stateAccounts'];
+  function MailboxesController($scope, $state, $transitions, $timeout, $window, $mdUtil, $mdMedia, $mdSidenav, $mdDialog, $mdToast, sgConstant, focus, encodeUriFilter, Dialog, Settings, sgHotkeys, Account, Mailbox, VirtualMailbox, User, Preferences, stateAccounts) {
     var vm = this,
         account,
         mailbox,
@@ -53,7 +53,7 @@
           key: hotkey,
           description: l('Delete selected message or folder'),
           callback: function() {
-            if (Mailbox.selectedFolderController && Mailbox.selectedFolder && !Mailbox.selectedFolder.hasSelectedMessage())
+            if (Mailbox.selectedFolderController && Mailbox.selectedFolder && Mailbox.selectedFolder.$isEditable && !Mailbox.selectedFolder.hasSelectedMessage())
               Mailbox.selectedFolderController.confirmDelete(Mailbox.selectedFolder);
           }
         }));
@@ -84,7 +84,8 @@
         var root, mailboxes = [],
             _visit = function(folders) {
               _.forEach(folders, function(o) {
-                mailboxes.push(o);
+                if (!o.isNoSelect())
+                  mailboxes.push(o);
                 if (o.children && o.children.length > 0) {
                   _visit(o.children);
                 }
@@ -102,14 +103,16 @@
         Mailbox.selectedFolder = vm.virtualMailbox;
         Mailbox.$virtualMode = true;
 
-        if (angular.isDefined(Mailbox.$virtualPath)) {
+        if (Mailbox.$virtualPath.length) {
           root = vm.accounts[0].$getMailboxByPath(Mailbox.$virtualPath);
           mailboxes.push(root);
           if (vm.search.subfolders && root.children.length)
             _visit(root.children);
         }
         else {
-          mailboxes = vm.accounts[0].$flattenMailboxes();
+          mailboxes = _.filter(vm.accounts[0].$flattenMailboxes({ all: true }), function(mailbox) {
+            return !mailbox.isNoSelect();
+          });
         }
 
         vm.virtualMailbox.setMailboxes(mailboxes);
@@ -120,32 +123,31 @@
     };
 
     this.addSearchParam = function(v) {
-      vm.currentSearchParam = v;
+      this.currentSearchParam = v;
       focus('advancedSearch');
       return false;
     };
 
     this.newSearchParam = function(pattern) {
-      if (pattern.length && vm.currentSearchParam.length) {
-        var n = 0, searchParam = vm.currentSearchParam;
+      if (pattern.length && this.currentSearchParam.length) {
+        var n = 0, searchParam = this.currentSearchParam;
         if (pattern.startsWith("!")) {
           n = 1;
           pattern = pattern.substring(1).trim();
         }
-        vm.currentSearchParam = '';
+        this.currentSearchParam = '';
         return { searchBy: searchParam, searchInput: pattern, negative: n };
       }
     };
 
     this.toggleAccountState = function (account) {
       account.$expanded = !account.$expanded;
-      account.$flattenMailboxes({ reload: true, saveState: true });
-      // Fire a window resize to recompute the virtual-repeater.
-      // This is a fix until the following issue is officially resolved:
-      // https://github.com/angular/material/issues/7309
-      $timeout(function() {
-        angular.element($window).triggerHandler('resize');
-      }, 150);
+      if (!this.debounceSaveState) {
+        this.debounceSaveState = $mdUtil.debounce(function () {
+          account.$flattenMailboxes({ reload: true, saveState: true });
+        }, 1000);
+      }
+      this.debounceSaveState();
     };
 
     this.subscribe = function(account) {
@@ -187,6 +189,13 @@
       }
     };
 
+    this.showAdvancedSearch = function() {
+      Mailbox.$virtualPath = '';
+      // Close sidenav on small devices
+      if (!$mdMedia(sgConstant['gt-md']))
+        $mdSidenav('left').close();
+    };
+
     this.newFolder = function(parentFolder) {
       Dialog.prompt(l('New Folder...'),
                     l('Enter the new name of your folder'))
