@@ -6,11 +6,13 @@
   /**
    * @ngInject
    */
-  MessageController.$inject = ['$window', '$scope', '$state', '$mdMedia', '$mdDialog', 'sgConstant', 'stateAccounts', 'stateAccount', 'stateMailbox', 'stateMessage', 'sgHotkeys', 'encodeUriFilter', 'sgSettings', 'ImageGallery', 'sgFocus', 'Dialog', 'Preferences', 'Calendar', 'Component', 'Account', 'Mailbox', 'Message'];
-  function MessageController($window, $scope, $state, $mdMedia, $mdDialog, sgConstant, stateAccounts, stateAccount, stateMailbox, stateMessage, sgHotkeys, encodeUriFilter, sgSettings, ImageGallery, focus, Dialog, Preferences, Calendar, Component, Account, Mailbox, Message) {
+  MessageController.$inject = ['$window', '$scope', '$q', '$state', '$mdMedia', '$mdDialog', 'sgConstant', 'stateAccounts', 'stateAccount', 'stateMailbox', 'stateMessage', 'sgHotkeys', 'encodeUriFilter', 'sgSettings', 'ImageGallery', 'sgFocus', 'Dialog', 'Preferences', 'Calendar', 'Component', 'Account', 'Mailbox', 'Message'];
+  function MessageController($window, $scope, $q, $state, $mdMedia, $mdDialog, sgConstant, stateAccounts, stateAccount, stateMailbox, stateMessage, sgHotkeys, encodeUriFilter, sgSettings, ImageGallery, focus, Dialog, Preferences, Calendar, Component, Account, Mailbox, Message) {
     var vm = this, popupWindow = null, hotkeys = [];
 
     this.$onInit = function() {
+      var isPopupWindow = false;
+
       // Expose controller
       $window.$messageController = vm;
 
@@ -30,9 +32,14 @@
 
       _registerHotkeys(hotkeys);
 
+      // Detect if this is message appears in a separate window
+      try {
+        isPopupWindow = $window.opener && '$mailboxController' in $window.opener;
+      }
+      catch (e) {}
+
       // One-way refresh of the parent window when modifying the message from a popup window.
-      if ($window.opener &&
-          '$mailboxController' in $window.opener) {
+      if (isPopupWindow) {
         // Update the message flags. The message must be displayed in the parent window.
         $scope.$watchCollection(function() { return vm.message.flags; }, function(newTags, oldTags) {
           var ctrls;
@@ -270,6 +277,7 @@
 
     function _showMailEditor($event, message) {
       if (_messageDialog() === null) {
+        var onCompleteDeferred = $q.defer();
         _messageDialog(
           $mdDialog
             .show({
@@ -280,9 +288,16 @@
               templateUrl: 'UIxMailEditor',
               controller: 'MessageEditorController',
               controllerAs: 'editor',
+              onComplete: function (scope, element) {
+                return onCompleteDeferred.resolve(element);
+              },
               locals: {
+                stateParent: $scope,
                 stateAccount: vm.account,
-                stateMessage: message
+                stateMessage: message,
+                onCompletePromise: function () {
+                  return onCompleteDeferred.promise;
+                }
               }
             })
             .catch(_.noop) // Cancel
