@@ -22,13 +22,18 @@
         data = {};
       }
 
-      // We swap $key -> _$key to avoid an Angular bug (https://github.com/angular/angular.js/issues/6266)
-      var labels = _.fromPairs(_.map(data.SOGoMailLabelsColors, function(value, key) {
-        if (key.charAt(0) == '$')
-          return ['_' + key, value];
-        return [key, value];
-      }));
-      data.SOGoMailLabelsColors = labels;
+      // Split mail labels keys and values
+      data.SOGoMailLabelsColorsKeys = [];
+      data.SOGoMailLabelsColorsValues = [];
+      _.forEach(data.SOGoMailLabelsColors, function (value, key) {
+        data.SOGoMailLabelsColorsKeys.push(key);
+        data.SOGoMailLabelsColorsValues.push(value); // value is an array of the user-defined name and color
+        if (key.charAt(0) == '$') {
+          Object.defineProperty(data.SOGoMailLabelsColors, '_' + key,
+                                Object.getOwnPropertyDescriptor(data.SOGoMailLabelsColors, key));
+          delete data.SOGoMailLabelsColors[key];
+        }
+      });
 
       _.forEach(data.SOGoSieveFilters, function(filter) {
         _.forEach(filter.actions, function(action) {
@@ -44,6 +49,8 @@
       // Mail editor autosave is a number of minutes or 0 if disabled
       data.SOGoMailAutoSave = parseInt(data.SOGoMailAutoSave) || 0;
 
+      data.SOGoMailComposeWindowEnabled = angular.isDefined(data.SOGoMailComposeWindow);
+
       // Specify a base font size for HTML messages when SOGoMailComposeFontSize is not zero
       data.SOGoMailComposeFontSizeEnabled = parseInt(data.SOGoMailComposeFontSize) > 0;
 
@@ -53,6 +60,11 @@
         window.CKEDITOR.addCss('.cke_editable { font-size: ' + data.SOGoMailComposeFontSize + 'px; }');
       }
 
+      _.forEach(data.AuxiliaryMailAccounts, function (mailAccount) {
+        if (isNaN(parseInt(mailAccount.port)))
+          mailAccount.port = null;
+      });
+
       // We convert our list of autoReplyEmailAddresses/forwardAddress into a string.
       // We also convert our date objects into real date, otherwise we'll have strings
       // or undefined values and the md-datepicker does NOT like this.
@@ -72,7 +84,9 @@
           data.Vacation.endDate = new Date(data.Vacation.startDate.getTime());
           data.Vacation.endDate.addDays(1);
         }
-        if (data.Vacation.autoReplyEmailAddresses && data.Vacation.autoReplyEmailAddresses.length)
+        if (data.Vacation.autoReplyEmailAddresses &&
+            angular.isArray(data.Vacation.autoReplyEmailAddresses) &&
+            data.Vacation.autoReplyEmailAddresses.length)
           data.Vacation.autoReplyEmailAddresses = data.Vacation.autoReplyEmailAddresses.join(",");
         else
           delete data.Vacation.autoReplyEmailAddresses;
@@ -96,16 +110,22 @@
         data.Vacation.endDate = new Date();
       }
 
-      if (data.Forward && data.Forward.forwardAddress)
+      if (data.Forward && data.Forward.forwardAddress &&
+          angular.isArray(data.Forward.forwardAddress))
         data.Forward.forwardAddress = data.Forward.forwardAddress.join(",");
 
-      if (angular.isUndefined(data.SOGoCalendarCategoriesColors)) {
-        data.SOGoCalendarCategoriesColors = {};
+      // Split calendar categories colors keys and values
+      if (angular.isUndefined(data.SOGoCalendarCategories))
         data.SOGoCalendarCategories = [];
-      }
+      data.SOGoCalendarCategoriesColorsValues = [];
+      _.forEach(data.SOGoCalendarCategories, function (value) {
+        data.SOGoCalendarCategoriesColorsValues.push(data.SOGoCalendarCategoriesColors[value]);
+      });
 
       if (angular.isUndefined(data.SOGoContactsCategories))
         data.SOGoContactsCategories = [];
+      else
+        data.SOGoContactsCategories = _.compact(data.SOGoContactsCategories);
 
       angular.extend(_this.defaults, data);
 
@@ -264,18 +284,13 @@
       }
     });
 
-    // We swap _$key -> $key to avoid an Angular bug (https://github.com/angular/angular.js/issues/6266)
-    labels = _.fromPairs(_.map(preferences.defaults.SOGoMailLabelsColors, function(value, key) {
-      if (key.charAt(0) == '_' && key.charAt(1) == '$') {
-        // New key, let's take the value and flatten it
-        if (key.length > 2 && key.charAt(2) == '$') {
-          return [value[0].toLowerCase().replace(/[ \(\)\/\{%\*<>\\\"]/g, "_"), value];
-        }
-        return [key.substring(1), value];
-      }
-      return [key, value];
-    }));
-    preferences.defaults.SOGoMailLabelsColors = labels;
+    // Merge back mail labels keys and values
+    preferences.defaults.SOGoMailLabelsColors = {};
+    _.forEach(preferences.defaults.SOGoMailLabelsColorsKeys, function(key, i) {
+      preferences.defaults.SOGoMailLabelsColors[key] = preferences.defaults.SOGoMailLabelsColorsValues[i];
+    });
+    delete preferences.defaults.SOGoMailLabelsColorsKeys;
+    delete preferences.defaults.SOGoMailLabelsColorsValues;
 
     _.forEach(preferences.defaults.SOGoSieveFilters, function(filter) {
       _.forEach(filter.actions, function(action) {
@@ -286,6 +301,10 @@
       });
     });
 
+    if (!preferences.defaults.SOGoMailComposeWindowEnabled)
+      delete preferences.defaults.SOGoMailComposeWindow;
+    delete preferences.defaults.SOGoMailComposeWindowEnabled;
+
     if (!preferences.defaults.SOGoMailComposeFontSizeEnabled)
       preferences.defaults.SOGoMailComposeFontSize = 0;
     delete preferences.defaults.SOGoMailComposeFontSizeEnabled;
@@ -313,6 +332,13 @@
     if (preferences.defaults.Forward && preferences.defaults.Forward.forwardAddress)
       preferences.defaults.Forward.forwardAddress = preferences.defaults.Forward.forwardAddress.split(",");
 
+    // Merge back calendar categories colors keys and values
+    preferences.defaults.SOGoCalendarCategoriesColors = {};
+    _.forEach(preferences.defaults.SOGoCalendarCategories, function(key, i) {
+      preferences.defaults.SOGoCalendarCategoriesColors[key] = preferences.defaults.SOGoCalendarCategoriesColorsValues[i];
+    });
+    delete preferences.defaults.SOGoCalendarCategoriesColorsValues;
+
     if (preferences.settings.Calendar && preferences.settings.Calendar.PreventInvitationsWhitelist) {
       _.forEach(preferences.settings.Calendar.PreventInvitationsWhitelist, function(user) {
         whitelist[user.uid] = user.$shortFormat();
